@@ -12,6 +12,10 @@ int main(int argc, char *argv[])
   //  }
   //  a.installTranslator(&translator);
     MainWindow w;
-    w.show();
+    if(argc > 2 && strncmp(argv[1],"nogui",5) == 0){
+        w.printTimes(argv[2]);
+    } else {
+        w.show();
+    }
     return a.exec();
 }
